==> marcelotsvaz_python_project_template-0.6.4.tar.gz: marcelotsvaz_python_project_template-0.6.4/readme.md <==
# 🐍 Python Project Template
Template to quickly bootstrap Python projects.

Uses [PDM](https://pdm.fming.dev/) to manage dependencies, build distributions and publish to package repositories.


## ✨ Features
- Centralized configuration in `pyproject.toml`
- Dependency management with [PDM](https://pdm.fming.dev/)
- Testing with [unittest](https://docs.python.org/3/library/unittest.html)
- Linting with [Pylint](https://github.com/pylint-dev/pylint)
- Integration with [Visual Studio Code](https://code.visualstudio.com/)
- Building and publishing to [PyPI](https://pypi.org/)
- Documentation hosted on [GitLab Pages](https://docs.gitlab.com/ee/user/project/pages/)
- CI/CD with [GitLab](https://docs.gitlab.com/ee/ci/)
- Several useful examples
	- Type hints
	- Logging
	- CLI

For a detailed description of all features check the [documentation](https://marcelotsvaz.gitlab.io/python-project-template/documentation/) and the [examples](examples/).


## 📂 Project Structure
```
📂 Python Project Template
├─ 📁 .staging              Build artifacts and other ignored files
├─ 📁 .vscode               VS Code configuration
├─ 📁 build                 Build scripts and local PDM plugins
├─ 📂 doc                   Documentation
│  ├─ 📁 documentation      Sources for TODO documentation
│  └─ 📁 homepage           Project homepage on GitLab Pages
├─ 📁 examples              Examples
├─ 📁 project_template      Main package
├─ 📁 tests                 Tests for the main package
├─ 🔶 .gitignore            Git ignored files
├─ 🦊 .gitlab-ci.yml        GitLab CI/CD configuration
├─ 🔒 pdm.lock              Dependency lock file
├─ ⚙️ pyproject.toml        Project metadata and tool configuration
├─ 📄 readme.md             Readme (this file)
└─ 📜 unlicense.txt         License
```


## Contributing
TODO: Contributing.

==> marcelotsvaz_python_project_template-0.7.1.tar.gz: marcelotsvaz_python_project_template-0.7.1/readme.md <==
[![Gitlab pipeline status](https://img.shields.io/gitlab/pipeline-status/marcelotsvaz%2Fpython-project-template?logo=gitlab&label=Build)](https://gitlab.com/marcelotsvaz/python-project-template/-/pipelines/latest)
[![Code coverage](https://img.shields.io/gitlab/pipeline-coverage/marcelotsvaz%2Fpython-project-template?branch=main&label=Coverage)](https://gitlab.com/marcelotsvaz/python-project-template/-/pipelines/latest)
[![GitLab release](https://img.shields.io/gitlab/v/release/marcelotsvaz%2Fpython-project-template?logo=gitlab&label=Release)](https://gitlab.com/marcelotsvaz/python-project-template/-/releases/permalink/latest)
[![PyPI package](https://img.shields.io/pypi/v/marcelotsvaz-python-project-template?logo=python&logoColor=%23CCCCCC&label=PyPI)](https://pypi.org/project/marcelotsvaz-python-project-template/)


# 🐍 Python Project Template
Template to quickly bootstrap Python projects.

Uses [PDM](https://pdm.fming.dev/) to manage dependencies, build distributions and publish to package repositories.


## ✨ Features
- Centralized configuration in `pyproject.toml`
- Dependency management with [PDM](https://pdm.fming.dev/)
- Testing with [unittest](https://docs.python.org/3/library/unittest.html)
- Linting with [Pylint](https://github.com/pylint-dev/pylint)
- Integration with [Visual Studio Code](https://code.visualstudio.com/)
- Building and publishing to [PyPI](https://pypi.org/)
- Documentation hosted on [GitLab Pages](https://docs.gitlab.com/ee/user/project/pages/)
- CI/CD with [GitLab](https://docs.gitlab.com/ee/ci/)
- Several useful examples
	- Type hints
	- Logging
	- CLI

For a detailed description of all features check the [documentation](https://marcelotsvaz.gitlab.io/python-project-template/documentation/) and the [examples](examples/).


## 📂 Project Structure
```
📂 Python Project Template
├─ 📁 .staging              Build artifacts and other ignored files
├─ 📁 .vscode               VS Code configuration
├─ 📁 build                 Build scripts and local PDM plugins
├─ 📂 doc                   Documentation
│  ├─ 📁 documentation      Sources for TODO documentation
│  └─ 📁 homepage           Project homepage on GitLab Pages
├─ 📁 examples              Examples
├─ 📁 project_template      Main package
├─ 📁 tests                 Tests for the main package
├─ 🔶 .gitignore            Git ignored files
├─ 🦊 .gitlab-ci.yml        GitLab CI/CD configuration
├─ 🔒 pdm.lock              Dependency lock file
├─ ⚙️ pyproject.toml        Project metadata and tool configuration
├─ 📄 readme.md             Readme (this file)
└─ 📜 unlicense.txt         License
```


## Contributing
TODO: Contributing.
